import numpy as np


CODE_0 = {0: '',
          1: 'Real Part of Complex Data',
          2: 'Imaginary Part of Complex Data',
          3: '',  # Amplitude - leave blank because it is redundant when forming a label
          }


CODE_1 = {0: '',
          1: 'Sample',
          2: 'Reference',
          3: '',  # Ratioed - leave blank because it is redundant when forming a label
          }


CODE_2 = {0: '',
          1: 'Data Parameters',
          2: 'Instrument Parameters',
          3: 'Acquisition Parameters',
          4: 'Fourier Transform Parameters',
          5: 'Plot and Display Parameters',
          6: 'Optical Parameters',
          7: 'GC Parameters',
          8: 'Library Search Parameters',
          9: 'Communication Parameters',
          10: 'Sample Origin Parameters',
          11: 'Lab and Process Parameters',
          }


CODE_3 = {0: '',
          1: 'Spectrum',
          2: 'Interferogram',
          3: 'Phase',
          4: 'Absorbance',
          5: 'Transmittance',
          6: 'Kubelka-Munk',
          7: 'Trace (Intensity over time)',
          8: 'gc File, Series of Interferograms',
          9: 'gc File, Series of Spectra',
          10: 'Raman',
          11: 'Emisson',
          12: 'Reflectance',
          13: 'Directory',
          14: 'Power',
          15: 'log Reflectance',
          16: 'ATR',
          17: 'Photoacoustic',
          18: 'Result of Arithmatics, looks like Transmittance',
          19: 'Result of Arithmatics, looks like Absorbance',
          22: 'Match',
          }


CODE_4 = {0: '',
          1: 'First Derivative',
          2: 'Second Derivative',
          3: 'n-th Derivative',
          }


CODE_5 = {0: '',
          1: 'Compound Information',
          2: '(Series)',
          3: 'Molecular Structure',
          4: '(Compact)',
          5: 'History/Report',
          }

# care must be taken when using 3-letter keys to avoid cross contaminating with 3-char parameter keys
CODE_3_ABR = {0: '',
              1: '',  # sc - single channel  leave blank because it is redundant when paired with sm, rf
              2: 'ig',
              3: 'ph',
              4: 'a',
              5: 't',
              6: 'km',
              7: 'tr',
              8: 'gcig',
              9: 'gcsc',
              10: 'ra',
              11: 'e',
              12: 'r',
              13: 'dir',
              14: 'pw',
              15: 'logr',
              16: 'atr',
              17: 'pas',
              18: 'arit',
              19: 'aria',
              22: 'match',
              }


TYPE_CODE_LABELS = [CODE_0, CODE_1, CODE_2, CODE_3, CODE_4, CODE_5]


STRUCT_3D_INFO_BLOCK = [
    {'key': 'nss', 'fmt': 'i', 'dtype': np.int32},
    {'key': 'nsr', 'fmt': 'i', 'dtype': np.int32},
    {'key': 'nsn', 'fmt': 'i', 'dtype': np.int32},
    {'key': 'npt', 'fmt': 'i', 'dtype': np.int32},
    {'key': 'gfw', 'fmt': 'i', 'dtype': np.int32},
    {'key': 'gbw', 'fmt': 'i', 'dtype': np.int32},
    {'key': 'bfw', 'fmt': 'i', 'dtype': np.int32},
    {'key': 'bbw', 'fmt': 'i', 'dtype': np.int32},
    {'key': 'hfl', 'fmt': 'd', 'dtype': np.float64},
    {'key': 'lfl', 'fmt': 'd', 'dtype': np.float64},
    {'key': 'hff', 'fmt': 'd', 'dtype': np.float64},
    {'key': 'lff', 'fmt': 'd', 'dtype': np.float64},
    {'key': 'filter_size', 'fmt': 'i', 'dtype': np.int32},
    {'key': 'filter_type', 'fmt': 'i', 'dtype': np.int32},
    {'key': 'fxv', 'fmt': 'd', 'dtype': np.float64},
    {'key': 'lxv', 'fmt': 'd', 'dtype': np.float64},
    {'key': 'mny', 'fmt': 'd', 'dtype': np.float64},
    {'key': 'mxy', 'fmt': 'd', 'dtype': np.float64},
    {'key': 'csf', 'fmt': 'd', 'dtype': np.float64},
    {'key': 'pka', 'fmt': 'd', 'dtype': np.float64},
    {'key': 'pra', 'fmt': 'd', 'dtype': np.float64},
    {'key': 'pkl', 'fmt': 'i', 'dtype': np.int32},
    {'key': 'prl', 'fmt': 'i', 'dtype': np.int32},
    {'key': 'srt', 'fmt': 'd', 'dtype': np.float64},
    {'key': 'ert', 'fmt': 'd', 'dtype': np.float64},
]


SUBREPORT_TYPE_FMT = {
    3: '<i',
    4: '<i',
    5: '<f',
    6: '<d',
    7: '<i',
    # > 1000: '<s' where length = type int - 1000
}


Y_LABELS = {
    'sm': 'Sample Spectrum',
    'rf': 'Reference Spectrum',
    'igsm': 'Sample Interferogram',
    'igrf': 'Reference Interferogram',
    'phsm': 'Sample Phase',
    'phrf': 'Reference Phase',
    'a': 'Absorbance',
    't': 'Transmittance',
    'r': 'Reflectance',
    'km': 'Kubelka-Munk',
    'tr': 'Trace (Intensity over Time)',
    'gcig': 'gc File (Series of Interferograms)',
    'gcsc': 'gc File (Series of Spectra)',
    'ra': 'Raman',
    'e': 'Emission',
    'dir': 'Directory',
    'p': 'Power',
    'logr': 'log(Reflectance)',
    'atr': 'ATR',
    'pas': 'Photoacoustic',
    }


XUN_LABELS = {
    'wl': 'Wavelength',
    'wn': 'Wavenumber',
    'f': 'Frequency',
    'pnt': 'Points',
    'min': 'Minutes',
    'logwn': 'Log Wavenumber',
    }


PARAM_LABELS = {
    "0DT": "Date and Time of Measurement",
    "2DD": "2D Cutoff Value",
    "2DF": "2D Reduction Factor",
    "2DM": "Correlation Mode",
    "2DR": "2D Digital Resolution",
    "2DS": "2D Subtract Reference",
    "2WR": "2D Whole X Range",
    "2WY": "2D Whole Y Range",
    "2XE": "2D X End Frequency",
    "2XS": "2D X Start Frequency",
    "2YE": "2D Y End Frequency",
    "2YS": "2D Y Start Frequency",
    "3DI": "Direct integration, frequency 3",
    "3DT": "Relative (galvano) time in seconds",
    "3DX": "Relative (galvano) x-position in microns",
    "3DY": "Relative (galvano) y-position in microns",
    "3DZ": "Relative (galvano) z-position in microns",
    "4DI": "Direct integration, frequency 4",
    "5DI": "Direct integration, frequency 5",
    "6DI": "Direct integration, frequency 6",
    "AAD": "Array depth",
    "AAE": "Aperture exists",
    "AAH": "Array height",
    "AAR": "Automatic Accessory Recognition",
    "AAT": "Array type",
    "AAW": "Array width",
    "AAX": "Array x",
    "AAY": "Array y",
    "AAZ": "Array z",
    "ABA": "Abort Assemble",
    "ABM": "Autofocus before measurement",
    "ABP": "Absolute Peak Pos in Laser*2",
    "ABT": "Detector Board Type",
    "ACA": "Automatic calibration mode",
    "ACC": "Accessory",
    "ACL": "Automatic Calibration",
    "ACM": "Allow cleaning ATR crystal mode during measurement",
    "ACN": "Accessory name",
    "ACO": "Color",
    "ACP": "Active Page",
    "ACS": "Accessory",
    "ACX": "Width",
    "ACY": "Height",
    "ACZ": "Depth",
    "AD2": "AQP2 Adress",
    "ADA": "Ampl. Demodulation Angle",
    "ADC": "Ext. Analog Signals",
    "ADL": "Current ADC Left Channel",
    "ADP": "All Data Points",
    "ADR": "AQP Adress",
    "ADT": "Additional Data Treatment",
    "AEX": "Automatic Integration Time",
    "AF2": "Apodization Function",
    "AFI": "File index",
    "AFM": "0: normal aperture measurement 1: fine aperture measurement",
    "AFP": "Set ATR Focus Position",
    "AFR": "Automatic Fluorescence Rejection",
    "AFT": "Autofocus type",
    "AFX": "Automatic flourescence removal",
    "AG2": "Actual Signal Gain 2nd Channel",
    "AG3": "Actual Signal Gain 3rd Channel",
    "AG4": "Actual Signal Gain 4th Channel",
    "AGP": "Group",
    "AHD": "Hidden",
    "AHF": "Actual High Pass Filter",
    "AIA": "Aperture input angle as degree",
    "AID": "ID of Accessory",
    "AII": "Aperture image index",
    "AIN": "Aperture image name",
    "AIT": "Active IT Test",
    "ALA": "Detector area ratio free  or  Correction Parameter A",
    "ALB": "Correction Parameter B",
    "ALC": "Use baseline correction for LWN-Calibration (make ScSm horizontal), used for firmware (AAR.ini)",
    "ALF": "Actual Low Pass Filter",
    "ALM": "Align mode control",
    "ALR": "galvano scanner analyzer",
    "ALW": "Actual laser wavenumber",
    "AMA": "Ampl. Modulation Amplitude(V)",
    "AMC": "Microscope Absolute Condenser",
    "AMD": "Enforce measurement of spectra to database, 0: No, 1: Yes",
    "AMF": "Ampl. Modulation Frequency",
    "AMX": "Microscope Absolute X",
    "AMY": "Microscope Absolute Y",
    "AMZ": "Microscope Absolute Z",
    "AN1": "Analog Signal 1",
    "AN2": "Analog Signal 2",
    "ANO": "Operation",
    "ANX": "Array nx",
    "ANY": "Array ny",
    "ANZ": "Array nz",
    "AO1": "Set Analog Out 1",
    "AO2": "Set Analog Out 2",
    "AOF": "file name of the aperture test OPUS file",
    "AOO": "relative path for the aperture test OPUS file",
    "AOX": "Map Origin X",
    "AOY": "Map Origin Y",
    "AOZ": "Map Origin Z",
    "AP2": "Aperture Setting",
    "APA": "Aperture angle",
    "APC": "Calibrate Automatic PGN",
    "APF": "Apodization Function",
    "APG": "Actual preamplifier gain",
    "APH": "Aperture cy",
    "APR": "ATR Pressure",
    "APT": "Aperture Setting",
    "APW": "Aperture cx",
    "APX": "Array pos x",
    "APY": "Array pos y",
    "APZ": "Array pos z",
    "AQM": "Acquisition Mode",
    "AQR": "Acquisition to ram",
    "AR1": "Report type (0: single sample, 1: multi sample)",
    "AR2": "Path of setup file",
    "AR3": "Name of setup file",
    "AR4": "Output option (1: Printer, 2: Clipboard, 4: PDF, 8: CSV, 16: EMF, or sum of these values)",
    "AR5": "Path of output file",
    "AR6": "Name of output file",
    "ARA": "Adaptation for Raman",
    "ARG": "Actual Ref. Signal Gain",
    "ARL": "Optional target language for report",
    "ARO": "Overwrite parameter. e.g.: ARO='AR2=.\\;AR5=.\\;AR6=AnalysisReport;'",
    "ARP": "ROP2",
    "ARR": "List of ranges",
    "ARS": "Number of Background Scans",
    "ARU": "Spectrum files to be unloaded, hidden parameter",
    "ARV": "Auto Resolution X-Axis Step Value",
    "ASD": "Add Spectra in Setup functions connects to database, 0: No, 1: Yes",
    "ASG": "Actual Signal Gain",
    "ASM": "OVP Autosetup Silent Mode",
    "ASP": "Autosampler Port (com 1...n)",
    "ASR": "Autosampler Reload/Reset position",
    "ASS": "Number of Sample Scans",
    "AST": "Autosampler target position",
    "ASV": "Autosampler device",
    "ASW": "Autosampler configuration file",
    "ASX": "Autosampler current position",
    "ASY": "Autosampler specific e.g. current rack",
    "ATA": "Angle Triggered Acquisition",
    "ATI": "automatic integration time",
    "ATM": "Save ATR Maximum Position",
    "ATN": "Attenuator",
    "ATP": "ATR pressure",
    "ATR": "Set ATR Position",
    "ATT": "Annotation text",
    "ATW": "Set ATR Focus Warning Offset",
    "ATX": "Annotation Text",
    "ATY": "Type",
    "AUT": "Authentication for DB, 0: Windows authentication, 1: Database authentication",
    "AUX": "Parameters set by e.g. PROCESS or OPUSLAB",
    "AVA": "Av: Save As Av-File",
    "AVC": "Average Cluster class",
    "AVI": "If set to 1, the cluster with class 0 is ignored when AVC is 0",
    "AVL": "Average Cluster load file",
    "AVP": "Av: Save As Path",
    "AVS": "Av: Save As SDev-File",
    "AWC": "Add for Freq.Calib",
    "AWL": "Assemble with Report",
    "AWX": "Aperture width x",
    "AWY": "Aperture height y",
    "AX1": "spectrum frame wavenumber limit 1, hidden parameter",
    "AX2": "spectrum frame wavenumber limit 2, hidden parameter",
    "AXP": "XPos",
    "AXS": "Trace Index to use as Axis",
    "AY1": "spectrum frame value limit 1, hidden parameter",
    "AY2": "spectrum frame value limit 2, hidden parameter",
    "AYP": "YPos",
    "AZP": "ZPos",
    "BAQ": "Background timeout mode",
    "BAT": "Battery status",
    "BBW": "Number of Bad BW Scans",
    "BCO": "Exclude CO2 - Bands",
    "BCR": "Beamsplitter Changer rotate",
    "BCT": "Bleaching time",
    "BDM": "Brightfield/Darkfield filter mode",
    "BDP": "BMS Dynamics Parameter",
    "BDT": "Background Delta Time",
    "BFW": "Number of Bad FW Scans",
    "BGA": "Automatic Background",
    "BGT": "Background Type",
    "BIO": "Number of Iterations",
    "BIR": "Recalculate Possible Traces",
    "BLC": "Bleaching on",
    "BLD": "Building",
    "BLK": "Blocktype to Assemble",
    "BLT": "Background Lifetime",
    "BMA": "Overall Block Mean Array",
    "BME": "Baseline Method",
    "BMF": "Background Management Flags",
    "BMO": "Background mode",
    "BMS": "Beamsplitter Setting",
    "BNE": "New Entry",
    "BPO": "Number of Baseline Points",
    "BPX": "Position x",
    "BPY": "Position y",
    "BRI": "Background repeat interval",
    "BRK": "Break Command",
    "BSA": "Overall Block Standard Deviation Array",
    "BSF": "Background Spectrum File",
    "BTI": "Ratio block type index",
    "BTS": "Path to Bitmap",
    "BTV": "Upper boundary of trace value",
    "BXX": "Size x",
    "BYY": "Position y",
    "CAA": "Condenser Autofocus Aperture ON/OFF:",
    "CAC": "Apply nonnegative constraint on Concentrations",
    "CAE": "BAnd A End Point",
    "CAF": "Unscrambler Model Name",
    "CAM": "Coaddition mode",
    "CAN": "CAN Bus Command",
    "CAP": "Unscrambler Model Path",
    "CAS": "Band A Start Point",
    "CAW": "Band A Weight",
    "CBE": "Band B End Point",
    "CBS": "Band B Start Point",
    "CBT": "New Block Type",
    "CBW": "Band B Weight",
    "CBY": "To Clipboard",
    "CCE": "Band C End Point",
    "CCF": "Create a new file",
    "CCI": "Cluster index",
    "CCM": "Method",
    "CCN": "New Entry",
    "CCO": "Correlation condition",
    "CCS": "Band C Start Point",
    "CCT": "Temperature Correction Coefficient",
    "CCW": "Band C Weight",
    "CDB": "Datablock of OPUS Spectrum",
    "CDI": "Permanent Dialog",
    "CDL": "Lower definition level",
    "CDO": "Operation",
    "CDS": "Chrom Display Spectrum",
    "CDT": "Chrom Display Trace",
    "CDU": "Upper definition level",
    "CET": "Index of selected ClusterList Trace",
    "CFC": "Compensating Filter Coefficients",
    "CFE": "Low intensity power mode with DTGS",
    "CFI": "COMmunication Output File",
    "CFL": "Freeze lower",
    "CFN": "Target file name",
    "CFO": "Compensating Filter On",
    "CFS": "Low intensity power mode with DTGS",
    "CFU": "Freeze upper",
    "CFX": "X-Startpoint",
    "CH2": "Channel 2",
    "CHD": "Vial cooler D",
    "CHI": "Vial cooler I",
    "CHK": "Check Command",
    "CHN": "Measurement Channel",
    "CHP": "Vial cooler P",
    "CHV": "Channel when optic is vector",
    "CHX": "OVPX Measurement Channel",
    "CID": "Microscope Channel ID",
    "CIG": "Chemical Group",
    "CII": "Crosshair snapshot image index",
    "CIL": "Chemical Imaging Label",
    "CIM": "Chrom Integration Method",
    "CIN": "Chrom Integrate Trace",
    "CIT": "Camera Integration Time",
    "CIX": "Config Index",
    "CJP": "Path for Jcamp-File",
    "CLA": "Apply Closure Constraint",
    "CLB": "Lower bound",
    "CLC": "Number of levels",
    "CLD": "Limit Run Duration",
    "CLE": "Cleanness Test Threshold",
    "CLI": "ClusterList Index",
    "CLK": "Identification Method (0: Quick Compare 1: Library Search)",
    "CLL": "Cluster Lists",
    "CLM": "Calibration Mirror",
    "CLR": "Galvano scanner clear buffer",
    "CLT": "Last Laser Calibration",
    "CLV": "Contour Levels",
    "CLX": "X-Endpoint",
    "CMA": "Correlation mask",
    "CMC": "Nonnegativity Method for Concentrations",
    "CMD": "Max Run Duration minutes",
    "CME": "Method (2: Interpolation, 3: Reduce Resolution)",
    "CMG": "Command message",
    "CMM": "Cyclic measurement mode",
    "CMN": "Command Line",
    "CMS": "Nonnegativity Method for Spectra",
    "CMT": "Comment for History",
    "CMU": "Max Run Duration Units",
    "CNA": "Image name",
    "CNB": "Command number in sequence",
    "CNC": "Constraints: Number Of Components",
    "CNE": "New Entry",
    "CNI": "Constraints: Max. Iterations",
    "CNM": "Operator Name",
    "CNO": "Container number",
    "CO1": "COMmunication Port",
    "CO2": "Mode Line",
    "COF": "Copy Flags",
    "COL": "Spectra Color",
    "COM": "Compound Name",
    "COP": "Copy Path",
    "COR": "Correlation Test Mode",
    "COS": "Color Settings in Plot",
    "COT": "COMmunication Output Text",
    "CPB": "Array of spectra to be averaged",
    "CPF": "Compensation Filter Switch",
    "CPG": "Character encoding code page",
    "CPH": "Target path",
    "CPI": "Control Parameter Integral",
    "CPJ": "Outer motor integral",
    "CPL": "Kind of compression",
    "CPN": "CheckMeasParms measurement function name",
    "CPP": "Control Parameter Proportional",
    "CPQ": "Outer motor proportional",
    "CPR": "Copyright message",
    "CPS": "Mirror tilt integral",
    "CPT": "Mirror tilt proportional",
    "CPY": "Company",
    "CRB": "Result block",
    "CRI": "Calibration repeat interval",
    "CRM": "Correlation rejection mask",
    "CRO": "Camera readout mode",
    "CRP": "Condenser relative position",
    "CRR": "Correlation rejection reason",
    "CRS": "Use images from OPUS file for detection",
    "CRT": "Last Raman Calibration",
    "CSA": "Apply nonnegative constraint on Spectra",
    "CSD": "Method",
    "CSF": "Y - Scaling Factor",
    "CSH": "Color scheme",
    "CSM": "CSM Method name",
    "CSN": "New Entry",
    "CSP": "Path for Mol. structure-File",
    "CSR": "Cosmic Spike Removal",
    "CSS": "Service URI",
    "CST": "Command status",
    "CSV": "Chrom Save Mode",
    "CSX": "Cosmic spike removal",
    "CTD": "Calibration Delta Time",
    "CTL": "Chrom Trigger Level",
    "CTM": "Chrom Start Trigger Mode",
    "CTN": "Targetname",
    "CTP": "Path for Target-File",
    "CTR": "Sample Reference Channel Transmission Ratio",
    "CTS": "CCD Temperature Set",
    "CTT": "Calibration Delta Temperature",
    "CTV": "Conversion target of jcamp-files",
    "CTY": "Colormap type",
    "CUB": "Upper bound",
    "CUL": "Unload snapshot file",
    "CUN": "New Entry",
    "CVC": "Closure value",
    "CXD": "X-Direction",
    "CXU": "X Units: Convert nanometer or micrometer to wavenumber",
    "CYP": "Unit Command Type",
    "DAB": "Binning",
    "DAC": "Set Analog Out",
    "DAF": "initial filename for load",
    "DAP": "Data File Path",
    "DAQ": "Data Aquisition Status",
    "DAT": "Date of Measurement",
    "DBP": "Database Path",
    "DBT": "Data Block Type",
    "DDD": "DDE Data",
    "DDE": "DDE Interaction",
    "DDI": "DDE Item",
    "DDM": "Display during Measurement",
    "DDP": "Device Manager data path",
    "DDS": "DDE Server Name",
    "DDT": "DDE Topic",
    "DDX": "Map Delta X",
    "DDY": "Map Delta Y",
    "DDZ": "Map Delta Z",
    "DEB": "Debug Printer Mode",
    "DEE": "Deconv End Frequency",
    "DEF": "Deconvolution Factor",
    "DEL": "Delay Before Measurement",
    "DER": "Derivative",
    "DES": "Deconv Start Frequency",
    "DEV": "Print option",
    "DFC": "Number of Filter Coef.",
    "DFM": "Detector frame rate",
    "DFN": "File Name (Data Point Table)",
    "DFO": "Data Format",
    "DFR": "Digital Filter Reduction",
    "DGF": "Diagnosis Filter",
    "DGS": "Diagnosis Mode",
    "DI2": "Digital Filter",
    "DIA": "Universal command for diagnostics",
    "DIG": "Digital Filter",
    "DII": "Image index",
    "DIL": "Display lower level",
    "DIN": "Image name",
    "DIP": "Dipole Moment",
    "DIS": "Display",
    "DIU": "Display upper level",
    "DLI": "Search in default libray folder",
    "DLP": "Device Manager library path",
    "DLR": "Delay Between Repeats in Sec.",
    "DLU": "Repeat Units",
    "DLY": "Stabilization Delay",
    "DMA": "DMA extraction mode",
    "DMF": "DMA frequency of strain (Hz)",
    "DMP": "DMA phase of strain",
    "DMR": "Diameter (mm)",
    "DMS": "DMA additional phase shift",
    "DMX": "Multiplexed Data",
    "DNM": "Device name",
    "DNR": "Deconv Noise Reduction",
    "DPA": "Decimal Places, Abscissa",
    "DPD": "Decimal Separation",
    "DPF": "Data Point Format",
    "DPH": "Demod. Phase (Degrees)",
    "DPL": "Use File Limits",
    "DPM": "Department",
    "DPO": "Decimal Places, Ordinate",
    "DPS": "Number of division in the range of particles size",
    "DPX": "X Units",
    "DSI": "Deconv Stored Interactive",
    "DSP": "Deconv Line Shape",
    "DST": "Display text",
    "DT2": "Detector Setting 2",
    "DTB": "Background Delta Temperature",
    "DTC": "Detector Setting",
    "DTS": "Detector shape",
    "DTX": "Detector width",
    "DTY": "Detector height",
    "DUR": "Scan time (sec)",
    "DVI": "Interactive Deconvolution",
    "DWN": "Wavenumber step size",
    "DWR": "Deconv Whole Range",
    "DXU": "X Units",
    "DXY": "Delta x,y for Mikrotiter Plate",
    "DYU": "Y Units",
    "EAB": "Abort extraction if file exists",
    "EAC": "ATR crystal refraction index (0=ZnSe, 1=Ge, 2=Diamond)",
    "EAN": "Number of ATR reflections (Extended)",
    "EAO": "Method of ATR correction",
    "EAR": "Number of ATR reflections (Advanced)",
    "EAS": "Sample refraction index",
    "EAT": "ATR incidence angel [degree]",
    "EC0": "set channel 0",
    "EC1": "set channel 1",
    "EC2": "set channel 2",
    "EC3": "set channel 3",
    "ECO": "Coadd all to one",
    "EDA": "End Date",
    "EDI": "Endpoint direct integration",
    "EDM": "Interpolation mode for extract diagonal",
    "EDN": "Structure Editor Name",
    "EDP": "Structure Editor Path",
    "EDS": "Scaling Factor for Structure Conversion",
    "EDT": "Export Start Date",
    "EFA": "Evolving factor analysis",
    "EFX": "First Point",
    "EIF": "Filename for the exported image",
    "EIH": "Height of the image in pixels",
    "EII": "Index of the image in the data file",
    "EIL": "Extract index list",
    "EIN": "Image name",
    "EIP": "Path of the export directory",
    "EIR": "Resolution of the exported image in dpi",
    "EIT": "Format type of the exported image (BMP=0, JPG=1)",
    "EIU": "Unit used for the dimensions of width and height of the image (MM=0,CM=1,INCH=2)",
    "EIW": "Width of the image in pixels",
    "ELC": "Enable pixel-dependent LWN correction",
    "ELF": "Load extracted files",
    "ELO": "Loop Ende",
    "ELT": "Elapsed Lifetime",
    "ELX": "Last Point",
    "EMO": "Mode",
    "EN1": "Refraction Index n1",
    "EN2": "Refraction Index n2",
    "EN3": "Refraction Index n3",
    "ENC": "If non-zero, indicates that input parameters of a function are given in the specified encoding (as per Windows codepage identifiers, including CP_UTF8 etc).",
    "ENE": "Entry to extract to",
    "ENT": "Entry to extract from",
    "EPC": "Comment for Edit Parameter",
    "EPH": "Hidden parm for 'EditParameter-function' : Set only the parameters specified (CNM SNM SFM EPC RSN XTX YTX ZTX XAF YAF YAZ)",
    "EPM": "Dialog protected mode",
    "EPR": "Export Product",
    "EPS": "Emissivity",
    "EQ1": "Equilibrium time 1",
    "EQ2": "Equilibrium time 2",
    "EQ3": "Equilibrium time 3",
    "EQ4": "Equilibrium time 4",
    "ERC": "Error code",
    "ERF": "Error function",
    "ERO": "Open result view immediately ,  Print eval. results automatically",
    "ERR": "Error string",
    "ERT": "End time (sec)",
    "ES1": "Sign first echo-peak",
    "ES2": "Sign second echo-peak",
    "ESC": "EnableSCope",
    "ESR": "Export Serial Number",
    "ET1": "End Temperature 1",
    "ET2": "End Temperature 2",
    "ET3": "End Temperature 3",
    "ET4": "End Temperature 4",
    "ETG": "End Trigger Position",
    "ETY": "0: Spectra only export, 1: Delete spectra files only, 2: Delete all Information",
    "EUL": "Use index list for extract",
    "EVG": "Even Gradient",
    "EVT": "Event",
    "EWD": "Optional external program working directory",
    "EWN": "End wavenumber of QCLaser",
    "EWR": "Whole Range (0=no 1=yes)",
    "EXD": "Null",
    "EXE": "Extract to (0: To Block, 1: To End of file)",
    "EXP": "Experiment",
    "EXS": "Extract from (0: From Block, 1: From Beginning of file)",
    "FA1": "Scenario Name",
    "FA2": "Measuring Point Name",
    "FA3": "Recipe",
    "FA4": "Batch Number",
    "FAC": "BlockID of Source",
    "FAI": "0: normal aperture image 1: fallback aperture image",
    "FBL": "Index Blue",
    "FBW": "Forward/Backward Igram",
    "FC1": "Product Group",
    "FC2": "Product",
    "FCC": "Carbon Conversion Coefficient",
    "FCM": "Fast Command Mode",
    "FCN": "Charge Carrier Concentration",
    "FCO": "Oxygen Conversion Coefficient",
    "FD0": "Label Product Info 1",
    "FD1": "Value Product Info 1",
    "FD2": "Label Product Info 2",
    "FD3": "Value Product Info 2",
    "FD4": "Label Product Info 3",
    "FD5": "Value Product Info 3",
    "FD6": "Label Product Info 4",
    "FD7": "Value Product Info 4",
    "FD8": "Label Product Info 5",
    "FD9": "Value Product Info 5",
    "FDA": "Factory detector parameter for ATR channel",
    "FDR": "Factory detector parameter for reflection channel",
    "FDT": "Factory detector parameter for transmission channel",
    "FE1": "Device Typ",
    "FE2": "Device Description",
    "FE3": "Measurement Position Microplate",
    "FE4": "Sample Wheel Position",
    "FE5": "Spectral Series",
    "FEP": "X-Endpoint",
    "FF1": "Info Message Ident",
    "FF2": "Info Message Quant",
    "FFC": "Factor for Carbon",
    "FFO": "Factor for Oxygen",
    "FFT": "Maximum FT Size in K's",
    "FG1": "Comment Ident",
    "FG2": "Comment Quant",
    "FGR": "Index Green",
    "FHR": "FT Phase Resolution",
    "FHZ": "FT Phase Correction Mode",
    "FIM": "File name Incrementing Mode",
    "FKT": "Selected Action",
    "FLC": "F Prob Limit Concentration Outliers",
    "FLF": "File Load Flags",
    "FLP": "Flaps control",
    "FLR": "FT Limit Resolution",
    "FLS": "F Prob Limit Spectral Outliers",
    "FMD": "Filter Mode",
    "FME": "Carbox Method",
    "FMP": "File Manager Path",
    "FMS": "Percentage of all score coefficients",
    "FNC": "FT Detector Cutoff Freq.",
    "FNE": "FT Modulation Efficiency",
    "FNL": "Non Linearity Correction",
    "FNM": "File name",
    "FOC": "Focal Length",
    "FOF": "Offset",
    "FOR": "Formula",
    "FPE": "FPA exposure time (ms)",
    "FPG": "FPA gain",
    "FPM": "FPA parameter mode",
    "FPO": "FPA video offset",
    "FPP": "ZPD Position",
    "FPS": "Symmetric FT First Point",
    "FQ1": "X-Startpoint",
    "FQ2": "X-Endpoint",
    "FRB": "Binarization (0=off 1=on)",
    "FRC": "Cluster type (0=random 1=rectangle)",
    "FRD": "Index Red",
    "FRG": "Frequency ranges",
    "FRI": "Image index",
    "FRK": "Cluster label number",
    "FRL": "Threshold value",
    "FRN": "Full Rotation Time (s)",
    "FRR": "Cluster resolution",
    "FRS": "Minimum object size",
    "FRT": "Reference Wafer Thickness",
    "FRX": "Maximum object size",
    "FRY": "Name of the cluster trace for trace input",
    "FSB": "Factor Subset",
    "FSI": "Free Carrier Type",
    "FSL": "Slope",
    "FSM": "FT ZPD Search Mode",
    "FSO": "Factors to Store",
    "FSP": "X-Startpoint",
    "FSR": "ZPD Search Range",
    "FSS": "Full Scan",
    "FST": "Wafer Thickness",
    "FSY": "FT Symmetry",
    "FTA": "FT Apodization Function",
    "FTE": "FT End Freqency",
    "FTR": "FT Resolution Limit",
    "FTS": "FT Start Frequency",
    "FTT": "FT to do list",
    "FTY": "FFT type",
    "FUN": "Units",
    "FWR": "FIT Whole Range",
    "FXE": "FIT End Frequency",
    "FXP": "Peak Pick Start Frequency",
    "FXS": "FIT Start Frequency",
    "FXV": "Frequency of First Point",
    "FY1": "Temperature",
    "FY2": "Pressure",
    "FY3": "Flow Rate",
    "FY4": "Flow Speed",
    "FY5": "Humidity",
    "FY6": "pH Value",
    "FY7": "Conductivity",
    "FYP": "Unit Firmware Type",
    "FZF": "FT Zero Filling Factor",
    "GAF": "PLSplus/IQ Calibration File Name",
    "GAP": "PLSplus/IQ Calibration File Path",
    "GAS": "galvano scanner averaging area shape",
    "GAX": "galvano scanner averaging area width",
    "GAY": "galvano scanner averaging area height",
    "GAZ": "galvano scanner averaging area depth",
    "GBS": "Go Back Short",
    "GBW": "Number of Good BW Scans",
    "GCV": "Get Command Value",
    "GDP": "Galvano scanner (x,y) position",
    "GDX": "Frame dx 12 cm",
    "GDY": "Frame dy 12 cm",
    "GER": "Get Motor [Unit] Resolution",
    "GET": "Get Parameter",
    "GFW": "Number of Good FW Scans",
    "GFX": "X-Startpoint",
    "GI0": "General Input Configuration 0",
    "GI1": "General Input Configuration 1",
    "GI2": "General Input Configuration 2",
    "GI3": "General Input Configuration 3",
    "GLD": "Gold standard reflectivity",
    "GLX": "X-Endpoint",
    "GMA": "Marker Symbol small circle",
    "GMC": "Marker Color CLR_NEUTRAL",
    "GMD": "Macro Description",
    "GMN": "Macro Filename",
    "GMS": "Marker Size",
    "GNE": "NewEntry",
    "GNK": "galvano scanner number of points for kinetics measurement",
    "GNS": "Signal Gain, Sample",
    "GNX": "galvano scanner num points x direction",
    "GNY": "galvano scanner num points y direction",
    "GNZ": "galvano scanner num points z direction",
    "GO0": "General Output Configuration 0",
    "GO1": "General Output Configuration 1",
    "GO2": "General Output Configuration 2",
    "GO3": "General Output Configuration 3",
    "GRA": "Grating name",
    "GRI": "GRI command?",
    "GRN": "Grating Name",
    "GRP": "Grating Position",
    "GRT": "Grating",
    "GSG": "Gain Switch Gain",
    "GSO": "Gram Schmidt Offset",
    "GSP": "Gram Schmidt Points",
    "GSQ": "GS Base Quality",
    "GSS": "Gram Schmidt Size",
    "GSW": "Gain Switch Window",
    "GSX": "galvano scanner x origin",
    "GSY": "galvano scanner y origin",
    "GSZ": "galvano scanner z origin",
    "GTI": "galvano scanner measurement time interval",
    "GTP": "Get Temperature",
    "GTU": "galvano scanner time unit",
    "GTX": "galvano scanner step width",
    "GTY": "galvano scanner step height",
    "GTZ": "galvano scanner step depth",
    "GUR": "Get Motor [Unit] Resolution",
    "GVM": "galvano scanner mode",
    "GXS": "Frame X Position 3 cm",
    "GYS": "Frame Y Position 2 cm",
    "H2O": "Mode of H2O-Compensation",
    "HAR": "Aromatics",
    "HBI": "Horizontal Binning",
    "HBL": "Bleaching Needed",
    "HCT": "Cell Thickness [cm]",
    "HDF": "Dilution Factor",
    "HEV": "Extract Vol [ml]",
    "HF2": "High Folding Limit 2nd Channel",
    "HF3": "High Folding Limit 3rd Channel",
    "HF4": "High Folding Limit 4th Channel",
    "HFF": "Digital Filter HFL",
    "HFL": "High Folding Limit",
    "HFQ": "End Frequency Limit for File",
    "HFW": "Wanted High Frequency Limit",
    "HIS": "History of Last Operation",
    "HML": "Instrument Humidity Limit %",
    "HMR": "Instrument Hunidity Range",
    "HMT": "Instrument Humidity Target",
    "HNM": "Host name",
    "HPF": "High Pass Filter",
    "HQ2": "End Frequency Limit for File",
    "HQU": "Hit Quality",
    "HSM": "Script with Measurement",
    "HSN": "Converted Script Name",
    "HSP": "Converted Script Path",
    "HSS": "Horizontal shift speed index",
    "HUA": "Absolute Humidity Interferometer",
    "HUM": "Relative Humidity Interferometer",
    "HWV": "Water Vol [l]",
    "IAX": "Initial value of Alignment X",
    "IAY": "Initial value of Alignment Y",
    "IBA": "Initial value of laser B Amplitude",
    "IBG": "Internal Background used",
    "ICT": "Icon Table Name",
    "IDA": "Annotation ID",
    "IDI": "Iris Diaphragm",
    "IDL": "Interleave Trigger Delay µsec",
    "IDM": "Iris Diaphragm Mode",
    "IDS": "Info Definition Description",
    "IDV": "Imaging Device Name",
    "IFN": "Correlation Table Filename",
    "IFP": "Correlation Table Path",
    "ILD": "Illumination Darkfield",
    "ILN": "Integration label name",
    "ILR": "Illumination Reflection",
    "ILT": "Illumination Transmission",
    "IM0": "Interferometer Motor 0",
    "IM1": "Interferometer Motor 1",
    "IME": "Integration Method , e. g., interactive - see INTEGRATION_... in evaluatef.h",
    "IMO": "Image path and name",
    "IMT": "Initialize Motor",
    "IMX": "Microscope Relative X",
    "IMY": "Microscope Relative Y",
    "INC": "FT Detector Cutoff Freq.",
    "INE": "FT Modulation Efficiency",
    "INL": "Information Search Query",
    "INM": "Info Definition Filename",
    "INP": "Info Text Path",
    "INR": "Instrument",
    "INS": "Instrument Type",
    "INT": "Integration Time",
    "IOP": "Image processing command name",
    "IP0": "Path of selected files",
    "IP1": "Path of selected folders",
    "IPD": "Destination Path",
    "IPN": "Names of selected files/folders",
    "IPS": "Selection of files (0) or folders (1)",
    "IPT": "Icon Table Path",
    "IPX": "Attach Image: Pos x",
    "IPY": "Attach Image: Pos y",
    "IRA": "blur radius",
    "IRC": "Microscope Relative Z",
    "IRD": "Delay of IR against laser in raw data periods",
    "IRS": "Iris Aperture (micron)",
    "IRZ": "Microscope Relative Z",
    "ISC": "Source image name",
    "ISP": "Interleave Time Res. µsec",
    "ISR": "InterLeaveSamplingRate",
    "IST": "Instrument Status",
    "IT1": "Instrument Test Path",
    "IT2": "Instrument Test Path 2",
    "IT3": "Instrument Test Path 3",
    "IT4": "Instrument Test Path 4",
    "IT5": "Instrument Test Path 5",
    "IT6": "Instrument Test Path 6",
    "ITC": "Instrument Test Channel",
    "ITF": "Interface Type for Optic",
    "ITG": "Target image name",
    "ITI": "Instrument Test Time",
    "ITM": "Integration time",
    "ITN": "Integration trace name",
    "ITO": "Inactivity timeout",
    "ITR": "Max. Exp. Trigger Rate Hz",
    "ITS": "Interleaved Time Slices",
    "ITV": "Threshold value",
    "IX1": "Instrument Test Path 7",
    "IX2": "Instrument Test Path 8",
    "IX3": "Instrument Test Path 9",
    "IX4": "Instrument Test Path 10",
    "IX5": "Instrument Test Path 11",
    "IX6": "Instrument Test Path 12",
    "IXD": "Firmware command IXD",
    "IXS": "Excluded Scans",
    "JAC": "JCAMP-DX Accept Comma",
    "JCC": "Generate JCAMP-DX Compound Files",
    "JCP": "JCAMP-DX Path",
    "JDF": "JCAMP-DX Date Format",
    "JDT": "JCAMP-DX Data Type",
    "JMW": "JMWs test command",
    "KAE": "Knifeedge Absolute East",
    "KAN": "Knifeedge Absolute North",
    "KAR": "Knifeedge Absolute Rotation",
    "KAS": "Knifeedge Absolute South",
    "KAW": "Knifeedge Absolute West",
    "KEA": "Knife edge angle (degrees)",
    "KEH": "Knife edge height (micron)",
    "KEW": "Knife edge width (micron)",
    "KEX": "End Frequency",
    "KFC": "Keep Function Change Information",
    "KIE": "Knifeedge Relative East",
    "KIN": "Knifeedge Relative North",
    "KIS": "Knifeedge Relative South",
    "KIW": "Knifeedge Relative West",
    "KKE": "KKT End Freqency",
    "KKR": "KKT result",
    "KKS": "KKT Start Frequency",
    "KLD": "Knife LED",
    "KMT": "KKT material (extrapol+cond/not cond)",
    "KNM": "Set Knife Edge Positioning Mode",
    "KOR": "Set Knife Edge Rotation Offset",
    "KRA": "Kinetics: initial concentration",
    "KRO": "Reaction order",
    "KRP": "whole x-range",
    "KRR": "Knifeedge Relative Rotation",
    "KRS": "Kinetics: Reaction velocity constant",
    "KRT": "Kinetics: Reaction n'th order",
    "KSX": "Start Frequency",
    "KTI": "zero based trace index",
    "KTX": "Whole x-Range (0=no 1=yes)",
    "KWR": "KKT Whole Range",
    "L50": "Lambda 50",
    "LAL": "Structure Search Algorithm",
    "LAS": "LAS command?",
    "LAT": "Layer Thickness",
    "LB0": "Defaults for Load Box",
    "LB1": "Library List",
    "LB2": "Default Parameters to scan for",
    "LB3": "Default Drives to scan",
    "LB4": "String to search for in CListScan",
    "LB5": "Coded parameters for CListScan",
    "LB6": "Indices for LoadBoxes",
    "LB7": "Method for Multi Evaluation",
    "LBA": "Library List (all)",
    "LBL": "Library Search Path",
    "LBM": "Last Background Measurement",
    "LBN": "Library Name",
    "LBP": "Library Path",
    "LBS": "Spectrum Number",
    "LBT": "Info Textfile Name",
    "LCF": "Max. Compression Factor",
    "LCH": "High Correlation Limit",
    "LCL": "Low Correlation Limit",
    "LCN": "Converted product file type (OPX or XML)",
    "LCO": "LancIR Communication Port",
    "LCP": "Copyright Note",
    "LCT": "Location",
    "LCX": "X coordinate of LWN correction model center",
    "LCY": "Y coordinate of LWN correction model center",
    "LDM": "LWN mismatch (in promille)",
    "LDO": "Miscellaneous flags: 1<<0 : Show intermediate spectra of calculation",
    "LDR": "Wavenumber in which range the water bands shall be compared",
    "LDS": "Significance of the correlation maximum",
    "LF2": "Low Folding Limit 2nd Channel",
    "LF3": "Low Folding Limit 3rd Channel",
    "LF4": "Low Folding Limit 4th Channel",
    "LFC": "Line focus",
    "LFF": "Digital Filter LFL",
    "LFL": "Low Folding Limit",
    "LFN": "Method Filename",
    "LFO": "Peak Label Font",
    "LFQ": "Start Frequency Limit for File",
    "LFT": "Device Lifetime",
    "LFW": "Wanted Low Frequency Limit",
    "LGL": "Log level",
    "LGN": "Laser Gain",
    "LGO": "BRUKER Logo",
    "LID": "Library Description",
    "LJF": "Lab journal file",
    "LLF": "Leverage Limit Factor",
    "LLP": "Library List Path",
    "LME": "Method",
    "LMN": "Method ID",
    "LMO": "Library Edit Mode",
    "LMT": "Method File Name",
    "LN2": "Laser Wavenumber 2nd Channel",
    "LN3": "Laser Wavenumber 3rd Channel",
    "LN4": "Laser Wavenumber 4th Channel",
    "LNC": "Expected number of components",
    "LNE": "New Entry",
    "LNO": "Laser Neon Offset",
    "LNP": "OPUSLab product name",
    "LOA": "Laser Offset laser A",
    "LOB": "Laser Offset laser B",
    "LOG": "Logfile for Measurement",
    "LON": "Library Name for Correlation Chart",
    "LOP": "Library Path for Correlation Chart",
    "LP1": "Password Read",
    "LP2": "Password Write",
    "LPB": "Bleaching laser power",
    "LPD": "directory of OPUSLab product",
    "LPF": "Low Pass Filter",
    "LPH": "Laser Peak Height",
    "LPM": "laser power sample measurement",
    "LPP": "Lines per Page",
    "LPR": "Library Protection",
    "LPS": "Symmetric FT Last Point",
    "LPT": "Integration Method Path",
    "LPV": "Variable Low Pass Filter(cm-1)",
    "LPW": "Laser Peak Width",
    "LPX": "Laser Position (Pixel)",
    "LQ2": "Start Frequency Limit for File",
    "LRI": "Handle missing info block (0=Edit, 1=create standard, 2=skip spectrum)",
    "LRM": "Integration Report Storage Mode",
    "LRU": "Sequence of actions available in wizard",
    "LS0": "List of more Filenames",
    "LS1": "Laser SureCal Coefficient 1",
    "LS2": "Laser SureCal Coefficient 2",
    "LS3": "Laser SureCal Coefficient 3",
    "LS4": "Laser SureCal Coefficient 4",
    "LSM": "Library Store Mode",
    "LSN": "Laser serial number",
    "LSR": "Show Results in a MessageBox",
    "LSS": "Search Sensitivity",
    "LST": "List of Filenames",
    "LTA": "Peak Sensitivity",
    "LTE": "End wave number",
    "LTI": "Increment step",
    "LTM": "Smoothing",
    "LTP": "Path for Library Text Definitions",
    "LTR": "Refraction Index",
    "LTT": "Start wave number",
    "LTV": "Automatic peak sensitivity determination",
    "LTX": "Whole x-Range (0=no 1=yes)",
    "LVN": "Library Name for Browser",
    "LVP": "Library Path for Browser",
    "LW2": "LWN correction model multiplication factor (x10-9)",
    "LWF": "LWN correction model multiplication factor",
    "LWN": "Laser Wavenumber",
    "LXP": "Peak Pick End Frequency",
    "LXV": "Frequency of Last Point",
    "LYS": "Scaling (0=Preserve y-Values 1=Preserve Integrals)",
    "M00": "Plot Message # 0",
    "M01": "Plot Message # 1",
    "M02": "Plot Message # 2",
    "M03": "Plot Message # 3",
    "M04": "Plot Message # 4",
    "M05": "Plot Message # 5",
    "M06": "Plot Message # 6",
    "M07": "Plot Message # 7",
    "M08": "Plot Message # 8",
    "M09": "Plot Message # 9",
    "MAG": "Communication format type",
    "MAT": "WindowMaterial (0=Quartz, 1=Saphir)",
    "MAU": "String to specify warning or alarm limits for quantitative results used in the ME Test function",
    "MAX": "X Measurement Position",
    "MAY": "Y Measurement Position",
    "MAZ": "Z Measurement Position",
    "MBP": "Multi Evaluation Base Path",
    "MBS": "Special Multi Evaluation Base Path",
    "MC0": "Colour trace 0",
    "MC1": "Colour trace 1",
    "MC2": "Colour trace 2",
    "MC3": "Colour trace 3",
    "MC4": "Colour trace 4",
    "MC5": "Colour trace 5",
    "MC6": "Colour trace 6",
    "MC7": "Colour trace 7",
    "MCC": "Correlation conditions met",
    "MCD": "Measurement Command Mode",
    "MCH": "Microscope Channel",
    "MCI": "Map Compute Integrals",
    "MCL": "Closure method",
    "MCM": "Map Macro",
    "MCP": "Measurement DLL Parameter",
    "MDA": "Detector slot specific detector to aperture magnification",
    "MDI": "Direct Integration: Method",
    "MDM": "Meas Display Mode",
    "MDN": "Measurement DLL NAME",
    "MDP": "Meas Display Product",
    "MDS": "Macro Description",
    "MDV": "Map Device",
    "MDX": "Map Sample Dim. X",
    "MDY": "Map Sample Dim. Y",
    "MEB": "String to specify an external bias for Quant 2 components used in ME Test function",
    "MEL": "Multi Eval Method List",
    "MEM": "Map Evaluation Macro",
    "MEN": "Multi Evaluation Method Name",
    "MEP": "Multi Evaluation Base Path",
    "MER": "Specifies the position of an analysis report line in the ME report, e.g. 2,3,1 means: Main Report 2, Sub Report 3, Row 1",
    "MEX": "Map Measurement Experiment",
    "MFD": "Max file delay in seconds for HTML transfer",
    "MFL": "Merge flags: 0=automatic, 1=Use defined ranges",
    "MFN": "Macro Filename",
    "MFS": "Max file size in megabytes for HTML transfer",
    "MGO": "Map Gram Schmidt Offset",
    "MGP": "Map Gram Schmidt Points",
    "MGS": "Map Gram Schmidt Size",
    "MGT": "Map Gram Schmidt",
    "MGX": "Map Gram Schmidt X Base",
    "MGY": "Map Gram Schmidt Y Base",
    "MIC": "Imaging Device",
    "MID": "Universally Unique Identifier - Measurement",
    "MIM": "Map Integration Method",
    "MIN": "Sample Meas. Duration in Min.",
    "MIR": "Background Meas. Duration in Min.",
    "MLS": "Map XY List",
    "MLW": "Minimum Spectrum Line Width in Plot",
    "MMI": "Merge Minimum Intensity",
    "MMK": "Moving Mean Manipulation Kind",
    "MMP": "Moving Mean Number of Points",
    "MMQ": "Measuring mode",
    "MMR": "Mode Mirror setting",
    "MMV": "Move Motors to preset",
    "MMX": "Measure Multiple XML Parameter",
    "MNA": "Minimum knife edge aperture size",
    "MND": "Make Monotone Direction",
    "MNM": "Merge result name",
    "MNS": "Measure number of coadditions",
    "MNY": "Y - Minimum",
    "MOF": "Modulation Frequency",
    "MOH": "Set Motor H?",
    "MOR": "Set motor @address to relative position",
    "MOS": "Set Motor S?",
    "MOT": "Set motor @address to absolute position",
    "MOX": "Map Origin X",
    "MOY": "Map Origin Y",
    "MP1": "1. Parameter for Multi Evaluation",
    "MP2": "2. Parameter for Multi Evaluation",
    "MP3": "3. Parameter for Multi Evaluation",
    "MP4": "4. Parameter for Multi Evaluation",
    "MP5": "5. Parameter for Multi Evaluation",
    "MPC": "Pump communication port",
    "MPD": "pump direction",
    "MPF": "amount of fluid",
    "MPH": "Merge result path",
    "MPL": "Instrument List Path",
    "MPM": "Pump operation mode",
    "MPO": "Map Port (com 1...n)",
    "MPP": "Show Search Report immediately",
    "MPQ": "Show Structure interprete view immediately",
    "MPS": "speed of fluid",
    "MPT": "Macro Path",
    "MPV": "Pump Control Device",
    "MPX": "Map # Pos X",
    "MPY": "Map # Pos Y",
    "MQC": "Preset Microscope Relative Condenser",
    "MQX": "Preset Microscope Relative X",
    "MQY": "Preset Microscope Relative Y",
    "MQZ": "Preset Microscope Relative X",
    "MRL": "Map Relative Origin",
    "MSC": "Microscope move till Switch Condenser",
    "MSH": "Map Shape (1..6)",
    "MSM": "Microscope detector selection mirror",
    "MSR": "Motor status register @address",
    "MSS": "Map Save Spectra",
    "MST": "LUMOS FastMapping Command List",
    "MSV": "Map Save Video",
    "MSX": "Map Spacing X",
    "MSY": "Map Spacing Y",
    "MSZ": "Microscope move till Switch Z",
    "MT0": "Trace 0",
    "MT1": "Trace 1",
    "MT2": "Trace 2",
    "MT3": "Trace 3",
    "MT4": "Trace 4",
    "MT5": "Trace 5",
    "MT6": "Trace 6",
    "MT7": "Trace 7",
    "MTC": "Multiple tracing: Generate Cluster Trace",
    "MTI": "Multiple tracing: Ignore Outlier",
    "MTN": "Number of traces",
    "MTP": "Path for Library Method Definitions",
    "MTR": "Maximum Transmission",
    "MTS": "Multiple tracing: SDev",
    "MTV": "Set Motor Velocity",
    "MTW": "Multiple tracing WTA",
    "MUN": "Map units",
    "MVC": "Microscope Velocity Condenser",
    "MVD": "Max. Velocity Deviation",
    "MVL": "Median Value",
    "MVM": "Map Video Method",
    "MVX": "Microscope Velocity X",
    "MVY": "Microscope Velocity Y",
    "MVZ": "Microscope Velocity Z",
    "MWC": "Mult. for Freq.Calib",
    "MXA": "Maximum knife edge aperture size",
    "MXD": "Maximum ADC Rate in Hz",
    "MXE": "Meas x-Endpoint Display",
    "MXS": "Meas x-Startpoint Display",
    "MXY": "Y - Maximum",
    "MYC": "MyInstrument Control",
    "MYE": "Meas y-Maximum Display",
    "MYN": "MyInstrument Script Name",
    "MYP": "MyInstrument Script Path",
    "MYS": "Meas y-Minimum Display",
    "N06": "N06 parameters (global options) as xml file",
    "NA2": "Ch. 2 Filename",
    "NA3": "Ch. 3 Filename",
    "NA4": "Ch. 4 Filename",
    "NAE": "Maximum allowed extrapolation in winner class (%, should be >100)",
    "NAM": "Filename",
    "NAN": "402040 parameter: Maximum activation of all other neurons",
    "NDF": "NeuroDeveloper Net Name",
    "NDP": "NeuroDeveloper Net Path",
    "NDV": "Map Device",
    "NF1": "First S/N Frequency Limit",
    "NF2": "Second S/N Frequency Limit",
    "NFL": "Nominal FW Peak Pos in Points",
    "NFO": "Also create System.nfo?",
    "NFX": "X-Startpoint",
    "NGS": "Number of basis vectors",
    "NGX": "Map Gram Schmidt X Base",
    "NGY": "Map Gram Schmidt Y Base",
    "NL2": "Non Linearity Correction",
    "NLA": "NL Alpha",
    "NLB": "NL Beta",
    "NLI": "Non Linearity Correction",
    "NLN": "Number of Scans Livestream NUC",
    "NLP": "Raman Nominal Laser Power in mW",
    "NLR": "Number of Scans Livestream Reference",
    "NLT": "Neon Light Source Type",
    "NLV": "Noise Level",
    "NLX": "X-Endpoint",
    "NME": "Method (1: Min-Max, 2: Vector, 3: Offset )",
    "NMP": "Total number of measurement positions",
    "NNE": "New Entry",
    "NNS": "Number of NUC Scans",
    "NOI": "Automatic Noise Calculation",
    "NOS": "Number of steps",
    "NOX": "Map Origin X",
    "NOY": "Map Origin Y",
    "NOZ": "Map Origin Z",
    "NPT": "Number of Data Points",
    "NPX": "Map Points in X",
    "NPY": "Map Points in Y",
    "NPZ": "Map Points in Z",
    "NSL": "Sample Scans Preview Measurement",
    "NSN": "Scan Number",
    "NSP": "Number of Smoothing Points",
    "NSR": "Background Scans",
    "NSS": "Sample Scans",
    "NST": "New Structure File",
    "NSX": "Map Spacing X",
    "NSY": "Map Spacing Y",
    "NTC": "Number of Tracks",
    "NTR": "number of tracks",
    "NUC": "NUC mode",
    "NWA": "WTA parameter: Minimum activation of winner neuron",
    "NWD": "WTA parameter: Minimum distance to next activation",
    "NWN": "402040 parameter: Minimum activation of winner neuron",
    "NWR": "Whole Range (0=no 1=yes)",
    "NXY": "Number x,y for Mikrotiter Plate",
    "OBJ": "Objective",
    "OBM": "Overall Block Mean",
    "OBS": "Overall Block Standard Deviation",
    "OBV": "Overall Block Variance",
    "ODQ": "OVP Data Query command",
    "OE1": "Overwrite (Data Point Table)",
    "OEX": "Overwrite Existing Files",
    "OF1": "Optical Filter Setting 1",
    "OF2": "Optical Filter Setting 2",
    "OF3": "Optical Filter Setting 3",
    "OF4": "Optical Filter Setting 4",
    "OFN": "Name of output file",
    "OFP": "Path of output file for average of cluster",
    "OFU": "OPUS function name in case of interactive otherwise else nor present",
    "OGS": "Offset from centerburst",
    "OIS": "Other instrument settings (XML-format)",
    "OLC": "ONET last connection",
    "ONA": "On new File Autoscale",
    "ONB": "On new File Browser",
    "OND": "On new File Display",
    "OOA": "FPA Optic Operator for atr channel",
    "OOC": "Current FPA Optic Operator",
    "OOR": "FPA Optic Operator for reflection channel",
    "OOT": "FPA Optic Operator for transmission channel",
    "OPF": "Optical Filter Setting",
    "OPT": "Option, corresponds to the buttons in LiveAperture dialog",
    "ORP": "Ordinate Precision",
    "OVS": "Overscan Range",
    "P2A": "Peak Amplitude 2nd Channel",
    "P2K": "Backward Peak Location 2nd Channel",
    "P2L": "Peak Location 2nd Channel",
    "P2R": "Backward Peak Amplitude 2nd Channel",
    "P3A": "Peak Amplitude 3rd Channel",
    "P3K": "Backward Peak Location 3rd Channel",
    "P3L": "Peak Location 3rd Channel",
    "P3R": "Backward Peak Amplitude 3rd Channel",
    "P4A": "Peak Amplitude 4th Channel",
    "P4K": "Backward Peak Location 4th Channel",
    "P4L": "Peak Location 4th Channel",
    "P4R": "Backward Peak Amplitude 4th Channel",
    "PAA": "Device Manager audit trail path",
    "PAC": "Preset Microscope Absolute Condenser",
    "PAT": "Path of File",
    "PAV": "Phase angle Value",
    "PBA": "Angle",
    "PBC": "Cutoff",
    "PBH": "Force Constant Helix",
    "PBL": "LeaveOut",
    "PBP": "Position CO",
    "PBS": "Force Constant Sheet",
    "PBT": "Force Constant Turn",
    "PBW": "Bandwidth",
    "PC2": "Process Control Code > 128kB",
    "PCB": "Process Batchnumber",
    "PCC": "Process Control Code",
    "PCD": "OPUS/ONet Product converting directory",
    "PCH": "Hide Script",
    "PCN": "Process Channel Name",
    "PCP": "Process Parameters",
    "PCR": "Product converting result",
    "PCS": "Process Script Name",
    "PCT": "Counts proportional to integration time",
    "PCW": "Wait for Script",
    "PCX": "OPUS/ONET alternative provided XPM file with path",
    "PD1": "Quant3 SVR Prediction, Spectrum File Path",
    "PD2": "Quant3 SVR Prediction, Spectrum File Name",
    "PDA": "Phase Demodulation Angle",
    "PDC": "Decay of Coupling",
    "PDH": "Plot Dialog Window Handle",
    "PDV": "Plot Device",
    "PEC": "PEM-Controller COM-port (com 1..n)",
    "PEE": "Experiment Type",
    "PEM": "Internal lockin for irras/vcd",
    "PER": "Retardation [Lambda]",
    "PEW": "Wavenumber [cm-1]",
    "PF1": "Plot Option Flags",
    "PFC": "Diagonal Force Constant",
    "PFI": "First Item Printed",
    "PFP": "Only prompt for",
    "PG2": "Preamplifier Gain, 2nd Channel",
    "PG3": "Preamplifier Gain, 3rd Channel",
    "PG4": "Preamplifier Gain, 4th Channel",
    "PGN": "Preamplifier Gain",
    "PGR": "Preamplifier Gain Background",
    "PGS": "Number of points used for basis vector",
    "PH2": "Phase Correction Mode",
    "PHR": "Phase Resolution",
    "PHZ": "Phase Correction Mode",
    "PIB": "Device Manager identification path",
    "PID": "Sample ID",
    "PIF": "Pipe Flags",
    "PIM": "Pressure Interferometer",
    "PIN": "Pipe Name",
    "PIS": "Pipe String",
    "PKA": "Peak Amplitude",
    "PKE": "Preset Knifeedge Absolute East",
    "PKL": "Peak Location",
    "PKN": "Preset Knifeedge Absolute North",
    "PKS": "Preset Knifeedge Absolute South",
    "PKW": "Preset Knifeedge Absolute West",
    "PL0": "Peak Label Size",
    "PL1": "Option Flags",
    "PL2": "'n' Strongest Peaks to Label",
    "PL3": "Decimals for Label Numbers",
    "PL4": "Length Stroke 0 - 1",
    "PL5": "Length Stroke 1 - 2",
    "PL6": "Length Stroke 2 - 3",
    "PL7": "Distance Peak <--> Line",
    "PL8": "Peak Stroke Length",
    "PLA": "Polarisation Angle",
    "PLC": "Wavenumber shift",
    "PLF": "Result Spectrum",
    "PLI": "Last Item Printed",
    "PLL": "Maximum PLL Setting",
    "PLN": "Plugin Name for OVP data query",
    "PLO": "Print Log File Name",
    "PLP": "Print Log Position on Screen",
    "PLR": "galvano scanner polarizer",
    "PLU": "List of last used scenario files",
    "PM1": "Quant3 SVR Prediction, Model File Path",
    "PM2": "Quant3 SVR Prediction, Model File Name",
    "PMA": "Device Manager materials path",
    "PMC": "Microscope Polarizer Camera",
    "PMR": "Microscope Polarizer Reflection",
    "PMT": "Microscope Polarizer Transmission",
    "PMX": "Preset Microscope Absolute X",
    "PMY": "Preset Microscope Absolute Y",
    "PMZ": "Preset Microscope Absolute Z",
    "PN1": "Plugin name 1 for OVP test",
    "PN2": "Plugin name 2 for OVP test",
    "PN3": "Plugin name 3 for OVP test",
    "PN4": "Plugin name 4 for OVP test",
    "PN5": "Plugin name 5 for OVP test",
    "PN6": "Plugin name 6 for OVP test",
    "PN7": "Plugin name 7 for OVP test",
    "PNC": "NC Shift",
    "PNP": "Peak Query Name",
    "PNR": "Port number",
    "PO1": "position generator type",
    "PO2": "number of positions in x direction",
    "PO3": "number of positions in y direction",
    "PO4": "x position of the first corner of the definition area",
    "PO5": "y position of the first corner of the definition area",
    "PO6": "x position of the oposite corner of the definition area",
    "PO7": "y position of the oposite corner of the definition area",
    "PO8": "position list for random positions",
    "PO9": "annotation position name list",
    "POF": "Plot & Print Output File Name",
    "POL": "Polarizer",
    "POP": "Plot & Print Output Path",
    "POS": "Return actual position",
    "PPA": "Polyline Parameters",
    "PPF": "Result Spectrum",
    "PPM": "Peak Pick Mode (Auto,Max,Min)",
    "PPN": "Number of Listed Peaks",
    "PPO": "Polarizer Position",
    "PPP": "Peak Query Path",
    "PPT": "Go to previous Step",
    "PPV": "Prepause",
    "PR2": "Preamplifier Gain Background, 2nd Channel",
    "PR3": "Preamplifier Gain Background, 3rd Channel",
    "PR4": "Preamplifier Gain Background, 4th Channel",
    "PRA": "Backward Peak Amplitude",
    "PRC": "Phase Rotation Automatic",
    "PRF": "Print Option Flags",
    "PRL": "Backward Peak Location",
    "PRM": "Protein Repeat Measurements",
    "PRN": "Print Device",
    "PRP": "Printer Port (LPTn)",
    "PRS": "Pressure Interferometer (hPa)",
    "PRT": "Phase Rotation",
    "PS0": "Product group name",
    "PS1": "Product name",
    "PS2": "Alias",
    "PS3": "Bitmap file path",
    "PS4": "Bitmap file name",
    "PS5": "Experiment file path",
    "PS6": "Experiment file name",
    "PS7": "ME file path",
    "PS8": "ME file name",
    "PSF": "PDB file",
    "PSM": "Peak Search Method",
    "PST": "Position type",
    "PTA": "Peak Threshold (Y-Units)",
    "PTC": "Process ASK THREAD Command",
    "PTH": "Measurement Path",
    "PTM": "Temperature Ramp mode",
    "PTR": "Peaks > [%]",
    "PTX": "Print Text",
    "PUD": "Ramp Up and Down mode",
    "PUN": "units (cm / inch)",
    "PVM": "LUMOS stage raise velocity",
    "PVV": "Vacuum/Purge",
    "PVZ": "Nominal Microscope Velocity Z",
    "PWN": "Parent Window",
    "PWO": "Plot WYSIWYG Options",
    "PWR": "Post Zf Whole Range (0=no 1=yes)",
    "PXY": "Proxy name for interactive mode",
    "PZE": "Post ZFF End Freqency",
    "PZF": "Post Zerofill Factor",
    "PZS": "Post ZFF Start Frequency",
    "QA0": "1: Consider Scans",
    "QA1": "1: Normalized Spectra",
    "QA2": "1: Average Report",
    "QA3": "Av. Spectrum Path",
    "QA4": "Av. Spectrum",
    "QA5": "1: Add to List in Ident Method",
    "QA6": "Assembled GC Spectrum Path",
    "QA7": "Assembled GC Spectrum",
    "QA8": "Assembled GC Start Frequency",
    "QA9": "Assembled GC End Frequency",
    "QAA": "Assembled GC Whole x-Range",
    "QAB": "Assembled GC Z Units",
    "QAC": "Assembled GC Z-Start",
    "QAD": "Assembled GC Z-End",
    "QAE": "Create Std-Dev Spectrum",
    "QAF": "Update Av. Spectrum",
    "QAG": "Updated Av. Spectrum Path",
    "QAH": "Updated Av. Spectrum",
    "QAI": "Adapting: New Entries",
    "QAJ": "Adapting: Method Path",
    "QAK": "Adapting: Method Name",
    "QAL": "Av.: Source of Orig. Spectra",
    "QAM": "Av: Orig. Spectra Path",
    "QAN": "Av: Orig. Spectra",
    "QAO": "Av: Orig. Spectra Block ID",
    "QAP": "Attach Image Path",
    "QAQ": "Attach Image File",
    "QAR": "Attach Image: Unit",
    "QAS": "Attach Image: x",
    "QAT": "Attach Image: y",
    "QAU": "Attach Image: Add Pos. Marker",
    "QAV": "Attach Image: Add Detect. Area",
    "QAW": "Attach Image: Diam. Detect. Area",
    "QAX": "AAR Thread Part",
    "QAY": "Crystal",
    "QBA": "Binning Factor",
    "QC0": "Raman Background Correction (0=no 1=yes)",
    "QC1": "Raman Scattering Correction (0=no 1=yes)",
    "QC2": "Undo Correction (0=no 1=yes)",
    "QC3": "Calibration Lamp Spectrum Path",
    "QC4": "Calibration Lamp Spectrum",
    "QC5": "Temp. of Calibration Lamp",
    "QC6": "2D-Corr. Whole x-Range",
    "QC7": "2D-Corr. Start Frequency",
    "QC8": "2D-Corr. End Frequency",
    "QC9": "2D-Corr. Limit Resolution",
    "QCA": "Method Path",
    "QCB": "Method Name",
    "QCC": "2D-Corr. Reduction Factor",
    "QCD": "2D-Corr. Synchronous",
    "QCE": "2D-Corr. Asynchronous",
    "QCF": "Conform. Test Method Path",
    "QCG": "Conform. Test Method File",
    "QCH": "Text-List Path",
    "QCI": "Text-List Name (incl. Ext.)",
    "QCJ": "Print/Plot",
    "QCK": "For Making Dendro",
    "QCL": "# of Classes (for Diagn.)",
    "QCN": "Method Filename",
    "QCO": "Compound Name",
    "QCP": "Method Path",
    "QCQ": "Print Results Automatically",
    "QCR": "Show Results Immediately",
    "QD0": "1: New Entries",
    "QD1": "Max. Number of Data Points",
    "QD2": "1st Data Point Line",
    "QDH": "Number of displayed hits",
    "QEF": "QM Export Manufactoring Order number FAUF",
    "QEK": "QM Export Customer order number KAUF",
    "QEL": "QM Export Pruef-Los",
    "QEM": "Evaluation Mode",
    "QEO": "QM Export Ovp Userdata xml file name",
    "QEP": "QM Export SAP password",
    "QEU": "QM Export SAP username",
    "QF0": "Restore Orig. Calib.",
    "QF1": "Quant 1 Method",
    "QF2": "Quant 2 Method",
    "QF3": "FIT Save Single Peaks Too",
    "QF4": "Start New FIT With Last Result",
    "QFA": "Show Results Immediately (0=no 1=yes)",
    "QFB": "Identity Test Methods",
    "QFC": "Method name",
    "QFD": "Use AQP Flag (0=no 1=yes)",
    "QFE": "No Ref. Def. (0); Sel. SNM or from table (1); Sel. Group-Name (2)",
    "QFF": "Expected Reference ID",
    "QFG": "Print Results Automatically (0=no 1=yes)",
    "QFH": "1st SNM char. for check",
    "QFI": "Length of SNM part for check",
    "QFJ": "Ident: Analy (0); Add List (1); Rem. All (2); Update AV.REP (3)",
    "QFK": "Ident: Path of Fl. to be Added",
    "QFL": "Ident: Name of Fl. to be Added",
    "QFN": "File List Name",
    "QFX": "Lower Compare Frequency Range",
    "QI0": "Ident: BlockID of Fl. to be Added",
    "QI1": "Sort for Expected Reference",
    "QI2": "1st SNM Char. for Sorting",
    "QI3": "Ident: Expected Group-Name",
    "QI4": "Ident: Store Av-Spectra",
    "QI5": "Ident: Print Library Tree",
    "QI6": "Page-size",
    "QI7": "Orientation",
    "QKE": "Preset Knifeedge Relative East",
    "QKN": "Preset Knifeedge Relative North",
    "QKS": "Preset Knifeedge Relative South",
    "QKW": "Preset Knifeedge Relative West",
    "QL0": "Whole x-Range (0=no 1=yes)",
    "QL1": "X-Startpoint",
    "QL2": "X-Endpoint",
    "QL3": "Data Points",
    "QL4": "Filter Index",
    "QLX": "Upper Compare Frequency Range",
    "QM0": "Assembled Map Units",
    "QM1": "Assembled Map x points",
    "QM2": "Assembled Map Delta x",
    "QM3": "Assembled Map y points",
    "QM4": "Assembled Map Delta y",
    "QM5": "Manip. GC: Macro Path",
    "QM6": "Manip. GC: Macro Filename",
    "QMA": "Fraction of Peak [%]",
    "QNE": "New Entries",
    "QOD": "Order of Derivative",
    "QP0": "Precision User Defined",
    "QP1": "Quant 1 Method Path",
    "QP2": "Quant 2 Method Path",
    "QP3": "Digits After Decimal Point",
    "QP4": "Upper Peak Limit",
    "QP5": "Peaks < [%]",
    "QP6": "Upper Peak Limit Abs.",
    "QP7": "Peaks < [abs.]",
    "QP8": "Lower Peak Limit Abs.",
    "QP9": "Peaks > [abs.]",
    "QPA": "Merging Peak Tables",
    "QPB": "More Info >> (0=no 1=yes)",
    "QPC": "Precision User Defined (intens.)",
    "QPD": "Digits After Decimal Point (intens.)",
    "QPH": "Energy (0), Photons (1)",
    "QPP": "Quant 2 Preprocessing Options",
    "QPT": "File List Path",
    "QQ0": "x-Start (x range 0)",
    "QQ1": "x-End   (x range 0)",
    "QQ2": "ymax-ymin(x range 0) must be >",
    "QQ3": "ymax-ymin(x range 0) must be <",
    "QQ4": "x-Start (x range 1)",
    "QQ5": "x-End   (x range 1)",
    "QQ6": "x-Start (x range 2)",
    "QQ7": "x-End   (x range 2)",
    "QQ8": "x-Start (x range noise)",
    "QQ9": "x-End   (x range noise)",
    "QQA": "y'max (x range noise) must be <",
    "QQB": "S/Noise (x range 1) must be >",
    "QQC": "S/Noise (x range 2) must be >",
    "QQD": "x-Start (x range water)",
    "QQE": "y'max (x water) must be <",
    "QQF": "S/Water (x range 1) must be >",
    "QQG": "S/Water (x range 2) must be >",
    "QQH": "x-End   (x range water)",
    "QQI": "x-Start (x range fringes)",
    "QQJ": "x-End   (x range fringes)",
    "QQK": "y'max (x fringes) must be <",
    "QQL": "Q-Test Method Path",
    "QQM": "Q-Test Method Name",
    "QQP": "Use File Limits",
    "QQQ": "No. of X-Ranges",
    "QQR": "X-Ranges",
    "QQS": "Normalized Spectra",
    "QQT": "Order of Derivative",
    "QQU": "No. of Smoothing Points",
    "QRS": "Quant 1 Show Results Immediately 0: No, 1: Yes",
    "QS0": "Smoothing points",
    "QS1": "Derivative",
    "QSM": "No of Smoothing Points",
    "QSP": "Number of Smoothing Points",
    "QT0": "Trace Cal.: Peak Integrals",
    "QT1": "Trace Cal.: Trace Points by Macro",
    "QT2": "Trace Cal.: Macro Path",
    "QT3": "Trace Cal.: Macro Filename",
    "QTE": "Temperature",
    "QTF": "Quant3 SVM Training File",
    "QTP": "Quant3 SVM Training Path",
    "QTU": "touch-up before measurement",
    "QUP": "Quant 2 Spectra List Upgrating",
    "QWD": "Use old peak width (hidden parameter: 0=no 1=yes)",
    "QWR": "Whole x-Range (0=no 1=yes)",
    "QX0": "Extrapol R (0)",
    "QX1": "Extrapol R (inf.)",
    "QX2": "Extrapol i1",
    "QX3": "Extrapol i2",
    "QX4": "Extrapol ny end",
    "R2D": "Index of Spectrum to be Replaced",
    "R2F": "Replace flags",
    "R2T": "Index of X axis trace",
    "R3D": "second Index of Spectrum",
    "RAT": "TRS Method name",
    "RB0": "Read bit 0",
    "RB1": "Read bit 1",
    "RB2": "Read bit 2",
    "RB3": "Read bit 3",
    "RBT": "Read Bit x",
    "RC0": "Raman Background Corrected",
    "RC1": "Raman Scattering Corrected",
    "RCA": "Calculate emissivity",
    "RCE": "Use constant emissivity",
    "RCF": "Rad. Calibration File",
    "RCH": "Background Measurement Channel",
    "RCM": "Ready conditions met",
    "RCN": "Rad. Calibration File Name",
    "RCP": "Rad. Calibration File Path",
    "RCS": "Rad. Calibration done",
    "RDD": "Raw Data Rate divisor for calculating the external trigger rate",
    "RDR": "Raw Data Rate in Hz",
    "RDS": "Number of time segments within raw data period",
    "RDX": "Extended Ready Check",
    "RDY": "Ready Check",
    "RE2": "Resolution Ch.2",
    "REA": "Method id",
    "REB": "username",
    "REF": "Emissivity spectrum file",
    "REN": "New File Name",
    "REP": "Repeat Count",
    "RES": "Resolution",
    "RF0": "floating point result value, could be used as return value from an OPUS function",
    "RF1": "floating point result value, could be used as return value from an OPUS function",
    "RF2": "floating point result value, could be used as return value from an OPUS function",
    "RF3": "floating point result value, could be used as return value from an OPUS function",
    "RF4": "floating point result value, could be used as return value from an OPUS function",
    "RF5": "floating point result value, could be used as return value from an OPUS function",
    "RF6": "floating point result value, could be used as return value from an OPUS function",
    "RF7": "floating point result value, could be used as return value from an OPUS function",
    "RF9": "floating point result value, could be used as return value from an OPUS function",
    "RFI": "Raman Filter RIM",
    "RFL": "Raman Flags",
    "RFN": "Reconstruction File Name",
    "RFP": "Reconstruction File Path",
    "RFR": "galvano scanner Raman Focus Lens",
    "RFT": "Raman Filter RIM",
    "RG2": "Signal Gain, Background 2nd Channel",
    "RG3": "Signal Gain, Background 3rd Channel",
    "RG4": "Signal Gain, Background 4th Channel",
    "RGN": "Signal Gain, Background",
    "RHN": "RSCB Host Name",
    "RHR": "Ramp heating rate deg/sec",
    "RI0": "integer result value, could be used as return value from an OPUS function",
    "RI1": "integer result value, could be used as return value from an OPUS function",
    "RI2": "integer result value, could be used as return value from an OPUS function",
    "RI3": "integer result value, could be used as return value from an OPUS function",
    "RI4": "integer result value, could be used as return value from an OPUS function",
    "RI5": "integer result value, could be used as return value from an OPUS function",
    "RI6": "integer result value, could be used as return value from an OPUS function",
    "RI7": "integer result value, could be used as return value from an OPUS function",
    "RI8": "integer result value, could be used as return value from an OPUS function",
    "RI9": "integer result value, could be used as return value from an OPUS function",
    "RIA": "Peak Sensitivity",
    "RIC": "Stage is calibrated",
    "RID": "Layer Thickness",
    "RIE": "End wave number",
    "RII": "Increment step",
    "RIM": "Smoothing",
    "RIR": "Refractive Index",
    "RIT": "Start wave number",
    "RIV": "Automatic peak sensitivity determination",
    "RIX": "Whole x-Range (0=no 1=yes)",
    "RLP": "Raman Laser Power in mW",
    "RLT": "Raman Laser Temperatur",
    "RLW": "Raman Laser Wavenumber",
    "RMC": "Reaction Monitoring Preprocessing",
    "RMD": "Rotation Mode",
    "RMF": "File name of ReactionAnalysis method",
    "RMI": "Reaction Monitoring Intermediates",
    "RMM": "Reaction Monitoring Materials",
    "RMN": "Reaction Monitoring Integration Methods",
    "RMP": "Path of ReactionAnalysis method",
    "RMR": "Reaction Monitoring Products",
    "RMS": "Reaction Monitoring Solvents",
    "RMX": "Resolution Limit",
    "RNA": "Number of axes",
    "RNF": "Number of Factors",
    "RNG": "Excluded Ranges File",
    "RNL": "Source of NL Correction parameters",
    "RNO": "Raman Neon Offset",
    "RNR": "Use New Result File",
    "RNT": "Spectral Range Text",
    "ROM": "Rotation Mode used by Firmware",
    "ROR": "Background Rotations",
    "ROS": "Sample Rotations",
    "ROT": "Rotations",
    "RPA": "Reference plate is available",
    "RPC": "Random point cluster data",
    "RPI": "Reference Position Id",
    "RPL": "Replay Line",
    "RPO": "Background Number",
    "RPP": "Print Report automatically",
    "RPS": "Show Report automatically",
    "RPW": "Reset password, old password not required",
    "RRL": "Line Separator (Write)",
    "RRS": "Show Results in a MessageBox",
    "RRT": "Terminator (Write)",
    "RS1": "Function Result",
    "RSN": "Running Sample Number",
    "RSP": "Camera readout speed",
    "RSR": "Read Write Mode",
    "RST": "Resolution Text",
    "RSV": "Runtime Saving Source",
    "RSY": "Reverse FT Symmetry",
    "RT0": "Coded Parameters for Edit Trace List",
    "RTA": "Ambient temperature (K)",
    "RTC": "Temperature (K) of cold black body",
    "RTH": "Temperature (K) of hot black body",
    "RTM": "Runtime Operating Source",
    "RTS": "Temperature (K, sample)",
    "RTX": "Text to send",
    "RUN": "Device Manager Command",
    "RWR": "Reverse FT Whole Range",
    "RWT": "Terminator (Read)",
    "RXC": "Stage x-coordinate",
    "RXE": "Reverse FT End Frequency",
    "RXS": "Reverse FT Start Frequency",
    "RYC": "Stage y-coordinate",
    "RZC": "Stage z-coordinate",
    "SAD": "Date",
    "SAM": "Sample String from ID-Chip",
    "SAN": "'Save As' File Name",
    "SB0": "Set bit 0",
    "SB1": "Set bit 1",
    "SB2": "Set bit 2",
    "SB3": "Set bit 3",
    "SBF": "Senterra binning factor",
    "SBJ": "Set Back Joystick Mode",
    "SBS": "Statistics Block Width",
    "SBT": "Set Bit x",
    "SC1": "Raman SureCal Coefficient 1",
    "SC2": "Raman SureCal Coefficient 2",
    "SC3": "Raman SureCal Coefficient 3",
    "SC4": "Raman SureCal Coefficient 4",
    "SCA": "SureCal",
    "SCC": "Correction Order Selection flag",
    "SCD": "Device Selection flag",
    "SCM": "Method Selection flag",
    "SCN": "Script Name",
    "SCP": "Script Path",
    "SCQ": "Simul Computed Quantity",
    "SDA": "Start Date",
    "SDD": "Simul Layer DF File",
    "SDE": "Simul Extract DF",
    "SDF": "Simuls Free Carriers",
    "SDI": "Startpoint direct integration",
    "SDL": "Simuls Lattice",
    "SDP": "Simul Layer DF",
    "SDT": "Sort data",
    "SDV": "Simuls Valence Electrons",
    "SDX": "Current (stage) x-position in microns",
    "SDY": "Current (stage) y-position in microns",
    "SDZ": "Current (stage) z-position in microns",
    "SEC": "ID Chip Sections",
    "SEI": "Simuls Epsilon Im[]",
    "SEN": "Unit Serial Number",
    "SEP": "Separator",
    "SER": "Simuls Epsilon Re[]",
    "SFB": "Split only Forward-Backward",
    "SFM": "Sample Form",
    "SFP": "Simuls Plasma Frequency",
    "SFS": "Simuls Scatter Frequency",
    "SFV": "Simul DF Values Flag",
    "SG2": "Signal Gain, Sample 2nd Channel",
    "SG3": "Signal Gain, Sample 3rd Channel",
    "SG4": "Signal Gain, Sample 4th Channel",
    "SGF": "Galvano scanner number of data points",
    "SGN": "Signal Gain, Sample",
    "SGP": "Switch Gain Position",
    "SGW": "Gain Switch Window",
    "SHN": "Spectrograph Host Name",
    "SHT": "Shutter mode",
    "SID": "MacID",
    "SIH": "Maximum Hits for Info Search",
    "SII": "User Index in Signature File",
    "SIM": "Meaning",
    "SIN": "Info Query Name",
    "SIP": "Info Query Path",
    "SIU": "UUID of user in userdatabase",
    "SJM": "Set Joystick Mode",
    "SLA": "Simul Angle Degrees",
    "SLC": "Selected OVP Test",
    "SLF": "Simul Layer Stack File",
    "SLI": "Simul Light From",
    "SLO": "Loop Start",
    "SLP": "Simul Polarization",
    "SLS": "Simul Layer Stack",
    "SMA": "Scanner Modulation Amplitude",
    "SMD": "Modulation (0=OFF 1=MOD 2=MOD-DEMOD 4=OLD PHASE 8=AMPL )",
    "SME": "Snapshot mode enumeration",
    "SMF": "Scanner Modulation Frequency",
    "SMI": "Index of selected Method Type in Sign Method function",
    "SMM": "Raman Imaging Meandering Mode (Senterra)",
    "SMN": "SAP Material Number",
    "SMO": "Smoothing points for der.",
    "SMS": "Scanner Maximal Output, steps",
    "SMU": "Multiplexer Option",
    "SMX": "Multiplexer positions",
    "SN1": "S/N (RMS)",
    "SN2": "S/N (Peak-to-Peak)",
    "SN3": "Max. Ordinate in S/N region",
    "SN4": "Min. Ordinate in S/N region",
    "SN5": "Noise (RMS)",
    "SN6": "Noise (Peak-to-Peak)",
    "SNC": "Snapshot image name crosshair detection",
    "SNF": "S/N Flags",
    "SNM": "Sample Name",
    "SNR": "Sample Changer",
    "SOF": "Set SRC Offset For 1% Output",
    "SOH": "Set Output x High",
    "SOL": "Set Output x Low",
    "SON": "External Synchronisation",
    "SOS": "Scantime or Scans",
    "SOT": "Sample Scans or Time",
    "SOX": "Sort X Values (Data Point Table)",
    "SP2": "Stored Phase Mode",
    "SPA": "Peak Search Algorithm",
    "SPB": "Sample Measurements per Background",
    "SPC": "Simuls Coherence",
    "SPD": "Simul Layer Density",
    "SPH": "Maximum Hits for Peak Search",
    "SPI": "Start position for the image stack",
    "SPM": "Protect Mode",
    "SPO": "Sample Number",
    "SPQ": "Minimum HQ for Peak Search",
    "SPS": "Source Power Save Mode",
    "SPT": "Simuls Type",
    "SPW": "Signature Password",
    "SPZ": "Stored Phase Mode",
    "SQN": "Packet sequence number",
    "SRC": "Source Setting",
    "SRG": "Spectral Range",
    "SRI": "Simul Extract DF Re/Im",
    "SRL": "Raman Laser Power(mW)",
    "SRM": "Send Report Mode",
    "SRN": "Instrument Serial Number",
    "SRR": "Spectral Range Name",
    "SRT": "Start time (sec)",
    "SRU": "Source used",
    "SRV": "Source Voltage",
    "SRX": "OVPX Source Setting",
    "SS1": "Spectrum Search Algorithm",
    "SSB": "Spectrum Substitution",
    "SSC": "Spectral Shape Correction",
    "SSE": "Step Scan Error",
    "SSF": "Senterra SG smoothing flag",
    "SSH": "Maximum Hits for Spectrum Search",
    "SSK": "Spectral shape correction",
    "SSM": "Sample Spacing Multiplicator",
    "SSO": "Searched Spectra Mode",
    "SSP": "Sample Spacing Divisor",
    "SSQ": "Minimum HQ for Spectrum Search",
    "SST": "Setpoint Sample Temperature",
    "SSV": "Saving Source Voltage",
    "SSY": "Symmetric FT Symmetry",
    "ST1": "Start temperature",
    "STA": "Ready Time after Saving Mode",
    "STB": "Timeout before Saving Mode",
    "STC": "Step Scan Coadd Count",
    "STD": "Step Scan Pos. Delay in msec",
    "STG": "Start Trigger Position",
    "STH": "Maximum Hits for Structure Search",
    "STL": "SetTimeRecord",
    "STM": "Statistics Method",
    "STN": "Structure File Name",
    "STO": "Scanner temperature offset",
    "STP": "Structure Path",
    "STR": "BG Scans or Time",
    "STV": "Lower boundary of trace value",
    "STW": "Step Width",
    "SUB": "Subtract Mode",
    "SUC": "SureCal",
    "SUI": "Interactive Subtract Parameter",
    "SUN": "Number of Spectra for Subtract",
    "SUO": "OVP XML Export options",
    "SVA": "Simuls Valence A",
    "SVB": "Simuls Valence B",
    "SVC": "Simuls Valence C",
    "SVG": "Simuls Energy Gap",
    "SVT": "Step View Time",
    "SVU": "Step View Units",
    "SWK": "Swap key",
    "SWN": "Start wavenumber of QCLaser",
    "SWR": "Simul Whole Range",
    "SWS": "Session Uuid",
    "SX1": "Start Frequency for Autosub",
    "SX2": "End Frequency for Autosub",
    "SXE": "Simul End Frequency",
    "SXP": "Simul Points",
    "SXS": "Simul Start Frequency",
    "SZL": "Simuls Lattice Count",
    "T3D": "3D Traces flags",
    "T71": "1st Temporary Shift for 785nm Laser",
    "T72": "2nd Temporary Shift for 785nm Laser",
    "T73": "3rd Temporary Shift for 785nm Laser",
    "T81": "1st Temporary Shift for 852nm Laser",
    "T82": "2nd Temporary Shift for 852nm Laser",
    "T83": "3rd Temporary Shift for 852nm Laser",
    "TAM": "True Alignment Mode",
    "TAP": "Light trap reflectivity",
    "TAW": "THz Analysis Width",
    "TAX": "Target value of Alignment X",
    "TAY": "Target value of Alignment Y",
    "TBA": "THz bias amplitude (V)",
    "TBF": "THz bias frequency (Hz)",
    "TBL": "Bleaching Time",
    "TBO": "Transpose selected block only",
    "TBP": "THz bias phase (degree)",
    "TC2": "Instrument Test Channel 2nd Channel",
    "TC3": "Instrument Test Channel 3rd Channel",
    "TC4": "Instrument Test Channel 4th Channel",
    "TCC": "CCD Temperature",
    "TCH": "Temperature Channel Index",
    "TCL": "Command line for Additional Data Treatment",
    "TCO": "Subtract",
    "TCP": "Twister Port (com 1...n)",
    "TCS": "Temperature Command String",
    "TD1": "Temperature difference 1",
    "TD2": "Temperature difference 2",
    "TD3": "Temperature difference 3",
    "TD4": "Temperature difference 4",
    "TDB": "Track Binning",
    "TDC": "Denominator constant",
    "TDE": "Track End Row",
    "TDI": "Denominator trace index",
    "TDL": "To do list",
    "TDP": "Twister destination position",
    "TDS": "Track Start Row",
    "TDV": "Temperature Control Device",
    "TFS": "THz Fast Scan",
    "TIB": "Reaction Monitoring Trace Info Block",
    "TID": "Trace GUID",
    "TIM": "Time of Measurement",
    "TIO": "Timeout",
    "TKF": "THz kinetics frequency (1/cm)",
    "TKN": "THz kinetics number of points",
    "TKT": "THz kinetics time between points (ms)",
    "TMC": "Twister Macro Command",
    "TML": "Instrument Temperatur Limit",
    "TMO": "Unit Timeout(s)",
    "TMP": "Temperature",
    "TMR": "Instrument Temperature Range",
    "TMT": "Instrument Temperature Target",
    "TNC": "Numerator constant",
    "TNI": "Numerator trace index",
    "TOB": "THz bias offset (V)",
    "TPD": "Use Com Defaults",
    "TPL": "Twister last vertical stack position",
    "TPO": "Temperature Port (com 1...n)",
    "TPS": "Twister source position",
    "TPT": "Twister Plate thickness",
    "TPX": "Total Points X",
    "TRC": "TRS Repeat Count",
    "TRD": "TRS Exp Delay in msec",
    "TRG": "Trigger Position",
    "TRI": "Index of the selected trace",
    "TRK": "CCD track list",
    "TRM": "TRS Experiment Trigger Mode",
    "TRN": "Trace name",
    "TRP": "TRS Positioning Delay",
    "TRQ": "Turn Frequency",
    "TRR": "TRS Resolution in micro sec",
    "TRS": "TRS Slices",
    "TRW": "Test Signal",
    "TRX": "TRS Sampling Source",
    "TS1": "Instrument Test Symbols",
    "TS2": "Instrument Test Symbols 2",
    "TS3": "Instrument Test Symbols 3",
    "TS4": "Instrument Test Symbols 4",
    "TS5": "Instrument Test Symbols 5",
    "TS6": "Instrument Test Symbols 6",
    "TSC": "Scanner Temperature",
    "TSD": "Trace ratio denominator selection",
    "TSF": "Spectra Transfer Method Name",
    "TSJ": "Type of JCAMP spectra, 0: Foss, 1: Büchi, 2: Bran+Luebbe, 3: Others: Absorbance, 4: Others: Transmittance",
    "TSM": "Sample Temperature",
    "TSN": "Trace ratio numerator selection",
    "TSP": "Spectra Transfer Method Path",
    "TSQ": "THz Square Spectrum",
    "TSR": "Additional Scan Range Points",
    "TSS": "Twister Stack size",
    "TST": "THz Result Spectrum Type",
    "TTA": "THz Transimpedence Amplifier",
    "TTR": "Temperature Tolerance Range",
    "TTS": "Tango Trend Selection",
    "TTV": "Trace Tolerance Value",
    "TVA": "TeraView Parameter String",
    "TVF": "Fast Scan Frequency",
    "TVI": "Step Scan Integration Time",
    "TVP": "Fast Scan Stage Position",
    "TVR": "Reference Laser Frequency",
    "TVS": "Step Scan Velocity",
    "TVT": "TeraView scan Type",
    "TWK": "Temperature work for thread",
    "TWN": "Tuning wn",
    "TX1": "Instrument Test Symbols 7",
    "TX2": "Instrument Test Symbols 8",
    "TX3": "Instrument Test Symbols 9",
    "TX4": "Instrument Test Symbols 10",
    "TX5": "Instrument Test Symbols 11",
    "TX6": "Instrument Test Symbols 12",
    "TYP": "Tango instrument type",
    "UAC": "Apply unimodality constraint on Concentrations",
    "UAS": "Use aperture images from OPUS file",
    "UCT": "Unimodality Tolerance for Concentrations",
    "UFL": "Use file limits",
    "UID": "Universally Unique Identifier",
    "ULN": "Use Login Name",
    "UMC": "Unimodality Method for Concentrations",
    "UME": "UME command?",
    "UMS": "Unimodality Method for Spectra",
    "UNI": "Command string for UNI",
    "URG": "Use PolySnap regression algorithm",
    "USA": "Apply unimodality constraint on Spectra",
    "USN": "Filename uses Sample Name",
    "USR": "User",
    "UST": "Unimodality Tolerance for Spectra",
    "UWN": "Channel Specific LWN",
    "VAC": "Vacuum/Flaps",
    "VAL": "Validation Base Path",
    "VB0": "Methode type flag",
    "VB1": "Autofocus flag",
    "VBH": "Hide Script",
    "VBI": "Vertical Binning",
    "VBP": "Script Parameters",
    "VBS": "VB Script Name",
    "VBW": "Wait for Script",
    "VCA": "VCD Calibration (LIA Sensitivity mV)",
    "VCD": "Valve control device",
    "VCI": "VCD Calibration is Interferogram or calculated",
    "VCN": "VCD Normalization",
    "VCP": "Valve control Port (com 1..n)",
    "VCT": "Valve target position",
    "VDT": "Vial Detection Intensity Threshold",
    "VEL": "Scanner Velocity",
    "VFL": "Validate Library: Use File Limits",
    "VFX": "Validate Library: X-Startpoint",
    "VHF": "VCD High Filter Limit",
    "VLB": "Validate Library: Bravo mode",
    "VLF": "VCD Low Filter Limit",
    "VLT": "Validate Library: Threshold",
    "VLV": "Valve control",
    "VLX": "Validate Library: X-Endpoint",
    "VMR": "relative flag",
    "VMX": "new X position",
    "VMY": "new y position",
    "VMZ": "new z position",
    "VNX": "no x movement",
    "VNY": "no y movement",
    "VNZ": "no z movement",
    "VPR": "VCD VCD-65-080602phaseres8",
    "VSA": "VCD Sample (LIA Sensitivity mV)",
    "VSC": "Variable Velocity (Hz)",
    "VSD": "DSP Firmware version",
    "VSN": "Firmware version",
    "VXF": "VCD Expand factor",
    "W2W": "Tr.Rec. Channel 2 Weighting",
    "WAR": "Tr.Rec. Resolution",
    "WAS": "Tr.Rec. Slices",
    "WDV": "Transient Recorder",
    "WEB": "Optional parameter for Quant 2 Analysis, analysis results shall be returned as string for Web Service",
    "WFA": "LWN-Fit: Curvature a / 10^(-9)",
    "WFE": "LWN-Fit: mean rel. fit error / 10^(-6)",
    "WFV": "LWN-Fit: LWN-Value at (C_X, C_Y)",
    "WFX": "LWN-Fit: Center Coord C_X",
    "WFY": "LWN-Fit: Center Coord C_Y",
    "WHR": "Whole x-Range (0=no 1=yes)",
    "WIB": "Tr.Rec. Input Range 2nd channel",
    "WIH": "Wait Input x High",
    "WIL": "Wait Input x Low",
    "WIR": "Tr.Rec. Input Range",
    "WND": "Optical windows",
    "WNO": "Wave Number",
    "WNS": "List of WNs",
    "WOP": "Work File Path",
    "WOU": "0: write all used image lines 1: write only used image lines",
    "WPA": "Tr.Rec. Input Path",
    "WPB": "Tr.Rec. Input Path 2nd channel",
    "WPD": "Tr.Rec. Stab. Delay after Stepping",
    "WRC": "Tr.Rec. Repeat Count",
    "WRF": "Whole Range (0=no 1=yes)",
    "WRK": "Measurement Command Type",
    "WRS": "Symmetric FT Whole Range",
    "WSS": "Tr.Rec. Sampling Source",
    "WSV": "X-Axis Step Value",
    "WTD": "Tr.Rec. Trigger Delay in points",
    "WTH": "Tr.Rec. Weighting Threshold",
    "WTL": "Tr.Rec. Trigger Level in mV",
    "WTM": "Tr.Rec. 50 Ohm",
    "WTP": "WTP command?",
    "WTR": "Tr.Rec. Resolution",
    "WTT": "Wait for x Milliseconds",
    "WVM": "Haar (0), Daubechies (1)",
    "WVT": "Threshold",
    "WXD": "Tr.Rec. Experiment Delay",
    "WXP": "Tr.Rec. Trigger Mode",
    "X64": "Base 64",
    "XAF": "X axis factor",
    "XAU": "X - Axis Scaling",
    "XCD": "Reference Detector Setting",
    "XCM": "Test Command Create Message",
    "XCO": "x Column (Data Point Table)",
    "XCW": "Close Window on Exit",
    "XDM": "VDM Settings Filename",
    "XE2": "Meas2 x-Endpoint Display",
    "XEM": "Windows Enhanced Mode",
    "XEP": "Right X Display Limit",
    "XMA": "Multiplexer dag0",
    "XMB": "Multiplexer dag1",
    "XND": "XA Delay in nsec",
    "XP1": "Instrument Test Experiments",
    "XP2": "Instrument Test Experiments 2",
    "XP3": "Instrument Test Experiments 3",
    "XP4": "Instrument Test Experiments 4",
    "XP5": "Instrument Test Experiments 5",
    "XP6": "Instrument Test Experiments 6",
    "XPA": "Parameters",
    "XPF": "Run as Opus Task",
    "XPM": "Old or New Function",
    "XPP": "Experiment Path",
    "XPR": "Program Name",
    "XS2": "Meas2 x-Startpoint Display",
    "XSA": "Scalefaktor DAG0",
    "XSB": "Start in Background",
    "XSM": "XsSamplingMode",
    "XSP": "Left X Display Limit",
    "XST": "Start Server",
    "XTI": "Increment Name (1=Name 0=Ext)",
    "XTM": "Extended TRS Mode",
    "XTN": "Extract Filename",
    "XTP": "Extract Path",
    "XTX": "X - Axis Label",
    "XVP": "View Transactions",
    "XWI": "Run in a Window",
    "XWN": "Channel specific LWN",
    "XWS": "Window Size Option",
    "XX1": "Instrument Test Experiments 7",
    "XX2": "Instrument Test Experiments 8",
    "XX3": "Instrument Test Experiments 9",
    "XX4": "Instrument Test Experiments 10",
    "XX5": "Instrument Test Experiments 11",
    "XX6": "Instrument Test Experiments 12",
    "XXA": "DSP-Testcommand",
    "XXR": "Read CAN Controller Register",
    "XXT": "Write CAN Controller Register",
    "XYZ": "All Coordinates",
    "YAF": "Y axis factor",
    "YCO": "y Column (Data Point Table)",
    "YE2": "Meas2 y-Maximum Display",
    "YMN": "Lower Y Display Limit",
    "YMX": "Upper X Display Limit",
    "YON": "y Values only",
    "YS2": "Meas2 y-Minimum Display",
    "YTX": "Y - Axis Label",
    "ZAF": "Z axis factor",
    "ZF2": "Zero Filling Factor",
    "ZFF": "Zero Filling Factor",
    "ZTX": "Z Axis Label",
    "_EP": "Send EWS parameter to DSP",
    "_GI": "Get Information",
    "_GP": "Get Intermediate Result",
    "_GR": "Get Result",
    "_ME": "Measure",
    "_MX": "Multiplexer IR/TRW",
    "_PS": "Periodic status request",
    "_SP": "Set Parameter",
    "_TR": "Trigger Measurement"
}